@@ -20,21 +20,21 @@ class CFX_BitStream {
 
   void ByteAlign();
 
-  bool IsEOF() const { return m_BitPos >= m_BitSize; }
-  size_t GetPos() const { return m_BitPos; }
+  bool IsEOF() const { return bit_pos_ >= bit_size_; }
+  size_t GetPos() const { return bit_pos_; }
   uint32_t GetBits(uint32_t nBits);
 
-  void SkipBits(size_t nBits) { m_BitPos += nBits; }
-  void Rewind() { m_BitPos = 0; }
+  void SkipBits(size_t nBits) { bit_pos_ += nBits; }
+  void Rewind() { bit_pos_ = 0; }
 
   size_t BitsRemaining() const {
-    return m_BitSize >= m_BitPos ? m_BitSize - m_BitPos : 0;
+    return bit_size_ >= bit_pos_ ? bit_size_ - bit_pos_ : 0;
   }
 
  private:
-  size_t m_BitPos = 0;
-  const size_t m_BitSize;
-  pdfium::raw_span<const uint8_t> const m_pData;
+  size_t bit_pos_ = 0;
+  const size_t bit_size_;
+  pdfium::raw_span<const uint8_t> const data_;
 };
 
 #endif  // CORE_FXCRT_CFX_BITSTREAM_H_
