@@ -9,12 +9,15 @@
 
 #include "include/private/base/SkTArray.h"
 #include "src/core/SkTraceEvent.h"
+#include "src/gpu/graphite/Buffer.h"
 #include "src/gpu/graphite/ComputePipeline.h"
 #include "src/gpu/graphite/ContextUtils.h"
 #include "src/gpu/graphite/GraphicsPipeline.h"
 #include "src/gpu/graphite/GraphicsPipelineDesc.h"
 #include "src/gpu/graphite/RenderPassDesc.h"
 #include "src/gpu/graphite/Resource.h"
+#include "src/gpu/graphite/ResourceProvider.h"
+#include "src/gpu/graphite/Sampler.h"
 #include "src/gpu/graphite/SharedContext.h"
 
 #if defined(SK_ENABLE_PRECOMPILE)
@@ -42,20 +45,22 @@ constexpr int kGlobalGraphicsPipelineCacheSizeLimit = 256;
 constexpr int kGlobalComputePipelineCacheSizeLimit = 256;
 #endif
 
-} // anonymous namespce
+} // anonymous namespace
 
 namespace skgpu::graphite {
 
 GlobalCache::GlobalCache()
         : fGraphicsPipelineCache(kGlobalGraphicsPipelineCacheSizeLimit, &fStats)
-        , fComputePipelineCache(kGlobalComputePipelineCacheSizeLimit) {}
+        , fComputePipelineCache(kGlobalComputePipelineCacheSizeLimit)
+        , fDynamicSamplers({}) {}
 
 GlobalCache::~GlobalCache() {
     // These should have been cleared out earlier by deleteResources().
-    SkDEBUGCODE(SkAutoSpinlock lock{ fSpinLock });
+    SkDEBUGCODE(SkAutoSpinlock lock{fSpinLock});
     SkASSERT(fGraphicsPipelineCache.count() == 0);
     SkASSERT(fComputePipelineCache.count() == 0);
     SkASSERT(fStaticResource.empty());
+    SkASSERT(fDynamicSamplers[0] == nullptr);
 }
 
 void GlobalCache::setPipelineCallback(PipelineCallback callback, PipelineCallbackContext context) {
@@ -82,8 +87,7 @@ void GlobalCache::invokePipelineCallback(SharedContext* sharedContext,
     }
 
     if (tmpCB) {
-        sk_sp<SkData> data = PipelineDescToData(sharedContext->caps(),
-                                                sharedContext->shaderCodeDictionary(),
+        sk_sp<SkData> data = PipelineDescToData(sharedContext->shaderCodeDictionary(),
                                                 pipelineDesc,
                                                 renderPassDesc);
 
@@ -119,13 +123,65 @@ void GlobalCache::invokePipelineCallback(SharedContext* sharedContext,
 }
 
 void GlobalCache::deleteResources() {
-    SkAutoSpinlock lock{ fSpinLock };
+    SkAutoSpinlock lock{fSpinLock};
+
+    for (int i = 0; i < kNumDynamicSamplers; ++i) {
+        fDynamicSamplers[i] = nullptr;
+    }
 
     fGraphicsPipelineCache.reset();
     fComputePipelineCache.reset();
     fStaticResource.clear();
 }
 
+bool GlobalCache::initializeDynamicSamplers(ResourceProvider* resourceProvider, const Caps* caps) {
+    SkAutoSpinlock lock{fSpinLock};
+
+    SkASSERT(fDynamicSamplers[0] == nullptr); // Must not already be initialized
+
+    static constexpr SkTileMode kTileModes[] = {SkTileMode::kClamp,
+                                                SkTileMode::kRepeat,
+                                                SkTileMode::kMirror,
+                                                SkTileMode::kDecal};
+    // Manually unroll the SkSamplingOptions that can be dynamic samplers to avoid nesting so many
+    // loops to create SamplerDescs. Cubic SkSamplingOptions do not need to contribute to this list.
+    // TODO: Support anisotropic filters
+    static constexpr SkSamplingOptions kSamplingOptions[] = {
+        {SkFilterMode::kNearest, SkMipmapMode::kNone},
+        {SkFilterMode::kLinear,  SkMipmapMode::kNone},
+        {SkFilterMode::kNearest, SkMipmapMode::kNearest},
+        {SkFilterMode::kLinear,  SkMipmapMode::kNearest},
+        {SkFilterMode::kNearest, SkMipmapMode::kLinear},
+        {SkFilterMode::kLinear,  SkMipmapMode::kLinear}
+    };
+
+    const bool supportsClampToBorder = caps->clampToBorderSupport();
+    for (auto samplingOption : kSamplingOptions) {
+        for (auto tileX : kTileModes) {
+            for (auto tileY : kTileModes) {
+                if (!supportsClampToBorder && (tileX == SkTileMode::kDecal ||
+                                               tileY == SkTileMode::kDecal)) {
+                    continue;
+                }
+
+                SamplerDesc dynamicDesc{samplingOption, {tileX, tileY}};
+                SkASSERT(!dynamicDesc.isImmutable() && dynamicDesc.asSpan().size() == 1);
+                sk_sp<Sampler> sampler =
+                        resourceProvider->findOrCreateCompatibleSampler(dynamicDesc);
+                if (!sampler) {
+                    return false;
+                }
+
+                // We already hold the spin lock, so add directly to fStaticResource
+                fStaticResource.emplace_back(sampler);
+                fDynamicSamplers[dynamicDesc.desc()] = sampler.get();
+            }
+        }
+    }
+
+    return true;
+}
+
 void GlobalCache::LogPurge(void* context, const UniqueKey& key, sk_sp<GraphicsPipeline>* p) {
     PipelineStats* stats = static_cast<PipelineStats*>(context);
 
@@ -159,10 +215,19 @@ sk_sp<GraphicsPipeline> GlobalCache::findGraphicsPipeline(
 
     sk_sp<GraphicsPipeline>* entry = fGraphicsPipelineCache.find(key);
     if (entry) {
+        if ((*entry)->didAsyncCompilationFail()) SK_UNLIKELY {
+            // If the pipeline failed, remove it from the cache and let it be regenerated.
+            this->removeGraphicsPipeline((*entry).get());
+            return nullptr;
+        }
 #if defined(GPU_TEST_UTILS)
         ++fStats.fGraphicsCacheHits;
 #endif
 
+        if ((*entry)->epoch() != fEpochCounter) {
+            (*entry)->markEpoch(fEpochCounter);   // update epoch due to use in a new epoch
+            ++fStats.fPipelineUsesInEpoch;
+        }
         if (!forPrecompile && (*entry)->fromPrecompile() && !(*entry)->wasUsed()) {
             ++fStats.fNormalPreemptedByPrecompile;
         }
@@ -241,6 +306,10 @@ sk_sp<GraphicsPipeline> GlobalCache::addGraphicsPipeline(const UniqueKey& key,
         ++fStats.fGraphicsCacheAdditions;
 #endif
 
+        SkASSERT((*entry)->epoch() == 0);
+        (*entry)->markEpoch(fEpochCounter);      // mark w/ epoch in which it was created
+        ++fStats.fPipelineUsesInEpoch;
+
         if ((*entry)->fromPrecompile()) {
             ++fStats.fUnpreemptedPrecompilePipelines;
         }
@@ -284,15 +353,36 @@ sk_sp<GraphicsPipeline> GlobalCache::addGraphicsPipeline(const UniqueKey& key,
                              "compilationID", pipeline->getPipelineInfo().fCompilationID);
 #endif
 
-#if SK_HISTOGRAMS_ENABLED
         SK_HISTOGRAM_ENUMERATION("Graphite.PipelineCreationRace",
                                  race,
                                  kPipelineCreationRaceCount);
-#endif
     }
     return *entry;
 }
 
+// Requires that the caller must have locked 'fSpinLock'
+void GlobalCache::removeGraphicsPipeline(const GraphicsPipeline* pipeline) {
+
+    skia_private::STArray<1, skgpu::UniqueKey> toRemove;
+    // This is only called when a pipeline failed to compile, so it is not performance critical.
+    fGraphicsPipelineCache.foreach([&toRemove, pipeline](const UniqueKey* key,
+                                                         const sk_sp<GraphicsPipeline>* inCache) {
+        // Since inCache is ref'ed by GlobalCache, we can safely compare direct addresses and not
+        // worry about a new GraphicsPipeline being allocated at an address that was still here.
+        if ((*inCache).get() == pipeline) {
+            toRemove.push_back(*key);
+        }
+    });
+
+    // The pipeline shouldn't have multiple unique keys, but this is structured to clean up every
+    // occurrence of pipeline in fGraphicsPipelineCache in release builds.
+    SkASSERT(toRemove.size() <= 1);
+
+    for (const skgpu::UniqueKey& k : toRemove) {
+        fGraphicsPipelineCache.remove(k);
+    }
+}
+
 void GlobalCache::purgePipelinesNotUsedSince(StdSteadyClock::time_point purgeTime) {
     SkAutoSpinlock lock{fSpinLock};
 
@@ -317,7 +407,7 @@ void GlobalCache::purgePipelinesNotUsedSince(StdSteadyClock::time_point purgeTim
     // TODO: add purging of Compute Pipelines (b/389073204)
 }
 
-void GlobalCache::reportPipelineStats() {
+void GlobalCache::reportPrecompileStats() {
     SkAutoSpinlock lock{fSpinLock};
 
     uint32_t numUnusedInCache = 0;
@@ -334,21 +424,43 @@ void GlobalCache::reportPipelineStats() {
     // If we see a lot of the counts hitting the over and under-flow buckets something
     // unexpected is happening and we would need to figure it out and, possibly, create
     // new UMA statistics for the observed range.
-    SK_HISTOGRAM_CUSTOM_COUNTS("Skia.Graphite.Precompile.NormalPreemptedByPrecompile",
-                               fStats.fNormalPreemptedByPrecompile,
-                               /* countMin= */ 1,
-                               /* countMax= */ 51,
-                               /* bucketCount= */ 50);
-    SK_HISTOGRAM_CUSTOM_COUNTS("Skia.Graphite.Precompile.UnpreemptedPrecompilePipelines",
-                               fStats.fUnpreemptedPrecompilePipelines,
-                               /* countMin= */ 100,
-                               /* countMax= */ 150,
-                               /* bucketCount= */ 50);
-    SK_HISTOGRAM_CUSTOM_COUNTS("Skia.Graphite.Precompile.UnusedPrecompiledPipelines",
-                               fStats.fPurgedUnusedPrecompiledPipelines + numUnusedInCache,
-                               /* countMin= */ 50,
-                               /* countMax= */ 100,
-                               /* bucketCount= */ 50);
+    SK_HISTOGRAM_CUSTOM_EXACT_LINEAR("Graphite.Precompile.NormalPreemptedByPrecompile",
+                                     fStats.fNormalPreemptedByPrecompile,
+                                     /* countMin= */ 1,
+                                     /* countMax= */ 51,
+                                     /* bucketCount= */ 52);
+    SK_HISTOGRAM_CUSTOM_EXACT_LINEAR("Graphite.Precompile.UnpreemptedPrecompilePipelines",
+                                     fStats.fUnpreemptedPrecompilePipelines,
+                                     /* countMin= */ 100,
+                                     /* countMax= */ 150,
+                                     /* bucketCount= */ 52);
+    SK_HISTOGRAM_CUSTOM_EXACT_LINEAR("Graphite.Precompile.UnusedPrecompiledPipelines",
+                                     fStats.fPurgedUnusedPrecompiledPipelines + numUnusedInCache,
+                                     /* countMin= */ 50,
+                                     /* countMax= */ 100,
+                                     /* bucketCount= */ 52);
+}
+
+void GlobalCache::reportCacheStats() {
+    SkAutoSpinlock lock{fSpinLock};
+
+    SK_HISTOGRAM_CUSTOM_EXACT_LINEAR("Graphite.PipelineCache.PipelineUsesInEpoch",
+                                     fStats.fPipelineUsesInEpoch,
+                                     /* countMin= */ 1,
+                                     /* countMax= */ 1001,
+                                     /* bucketCount= */ 102); // 10/bucket
+
+    // Set up for a new epoch
+    fStats.fPipelineUsesInEpoch = 0;
+    ++fEpochCounter;
+    if (!fEpochCounter) {
+        // The epoch counter has wrapped around - this should be *very* rare. Reset the cache.
+        fGraphicsPipelineCache.foreach([](const UniqueKey* key,
+                                          const sk_sp<GraphicsPipeline>* pipeline) {
+            (*pipeline)->markEpoch(0);
+        });
+        fEpochCounter = 1;
+    }
 }
 
 #if defined(GPU_TEST_UTILS)
@@ -372,6 +484,41 @@ void GlobalCache::forEachGraphicsPipeline(
         fn(*k, v->get());
     });
 }
+
+uint16_t GlobalCache::getEpoch() const {
+    SkAutoSpinlock lock{fSpinLock};
+
+    return fEpochCounter;
+}
+
+// The next reportCacheStats call after this will overflow
+void GlobalCache::forceNextEpochOverflow() {
+    SkAutoSpinlock lock{fSpinLock};
+
+    fEpochCounter = std::numeric_limits<uint16_t>::max();
+}
+
+// Get the offsets and sizes of the renderstep static uploads.
+void GlobalCache::testingOnly_SetStaticVertexInfo(
+        skia_private::TArray<StaticVertexCopyRanges> vertBufferInfo, const Buffer* vertBuffer) {
+    SkAutoSpinlock lock{fSpinLock};
+
+    fStaticVertexInfo = vertBufferInfo;
+    fStaticVertexBuffer = vertBuffer;
+}
+
+SkSpan<const GlobalCache::StaticVertexCopyRanges> GlobalCache::getStaticVertexCopyRanges() const {
+    SkAutoSpinlock lock{fSpinLock};
+
+    return SkSpan<const GlobalCache::StaticVertexCopyRanges>(fStaticVertexInfo);
+}
+
+sk_sp<Buffer> GlobalCache::getStaticVertexBuffer() {
+    SkAutoSpinlock lock{fSpinLock};
+
+    return sk_ref_sp(fStaticVertexBuffer);
+}
+
 #endif // defined(GPU_TEST_UTILS)
 
 GlobalCache::PipelineStats GlobalCache::getStats() const {
@@ -382,6 +529,7 @@ GlobalCache::PipelineStats GlobalCache::getStats() const {
 
 sk_sp<ComputePipeline> GlobalCache::findComputePipeline(const UniqueKey& key) {
     SkAutoSpinlock lock{fSpinLock};
+
     sk_sp<ComputePipeline>* entry = fComputePipelineCache.find(key);
     return entry ? *entry : nullptr;
 }
@@ -389,6 +537,7 @@ sk_sp<ComputePipeline> GlobalCache::findComputePipeline(const UniqueKey& key) {
 sk_sp<ComputePipeline> GlobalCache::addComputePipeline(const UniqueKey& key,
                                                        sk_sp<ComputePipeline> pipeline) {
     SkAutoSpinlock lock{fSpinLock};
+
     sk_sp<ComputePipeline>* entry = fComputePipelineCache.find(key);
     if (!entry) {
         entry = fComputePipelineCache.insert(key, std::move(pipeline));
@@ -398,6 +547,7 @@ sk_sp<ComputePipeline> GlobalCache::addComputePipeline(const UniqueKey& key,
 
 void GlobalCache::addStaticResource(sk_sp<Resource> resource) {
     SkAutoSpinlock lock{fSpinLock};
+
     fStaticResource.push_back(std::move(resource));
 }
 
