@@ -38,11 +38,13 @@
 #include "src/gpu/graphite/Caps.h"
 #include "src/gpu/graphite/CommandBuffer.h"
 #include "src/gpu/graphite/Device.h"
+#include "src/gpu/graphite/DrawContext.h"
 #include "src/gpu/graphite/Image_Graphite.h"
 #include "src/gpu/graphite/Log.h"
 #include "src/gpu/graphite/RecorderPriv.h"
 #include "src/gpu/graphite/ResourceProvider.h"
 #include "src/gpu/graphite/ResourceTypes.h"
+#include "src/gpu/graphite/RuntimeEffectDictionary.h"
 #include "src/gpu/graphite/SpecialImage_Graphite.h"
 #include "src/gpu/graphite/Surface_Graphite.h"
 #include "src/gpu/graphite/Texture.h"
@@ -260,10 +262,20 @@ std::tuple<TextureProxyView, SkColorType> MakeBitmapProxyView(Recorder* recorder
     // Add upload to the root upload list. These bitmaps are uploaded to unique textures so there is
     // no need to coordinate resource sharing. It is better to then group them into a single task
     // at the start of the Recording.
-    if (!recorder->priv().rootUploadList()->recordUpload(
-            recorder, proxy, colorInfo, colorInfo, texels,
-            SkIRect::MakeSize(bmpToUpload.dimensions()),
-            std::make_unique<ImageUploadContext>())) {
+    const SkIRect dimensions = SkIRect::MakeSize(bmpToUpload.dimensions());
+    UploadSource uploadSource = UploadSource::Make(
+            recorder->priv().caps(), *proxy, colorInfo, colorInfo, texels, dimensions);
+    if (!uploadSource.isValid()) {
+        SKGPU_LOG_E("MakeBitmapProxyView: Could not create UploadSource");
+        return {};
+    }
+    if (!recorder->priv().rootUploadList()->recordUpload(recorder,
+                                                         proxy,
+                                                         colorInfo,
+                                                         colorInfo,
+                                                         uploadSource,
+                                                         dimensions,
+                                                         std::make_unique<ImageUploadContext>())) {
         SKGPU_LOG_E("MakeBitmapProxyView: Could not create UploadInstance");
         return {};
     }
@@ -349,6 +361,7 @@ size_t ComputeSize(SkISize dimensions, const TextureInfo& info) {
 }
 
 sk_sp<Image> CopyAsDraw(Recorder* recorder,
+                        DrawContext* drawContext,
                         const SkImage* image,
                         const SkIRect& subset,
                         const SkColorInfo& dstColorInfo,
@@ -365,12 +378,12 @@ sk_sp<Image> CopyAsDraw(Recorder* recorder,
                                                         .makeAlphaType(kPremul_SkAlphaType));
     // The surface goes out of scope when we return, so it can be scratch, but it may or may
     // not be budgeted depending on how the copied image is used (or returned to the client).
-    auto surface = Surface::MakeScratch(recorder,
-                                        dstInfo,
-                                        std::move(label),
-                                        budgeted,
-                                        mipmapped,
-                                        backingFit);
+    sk_sp<Surface> surface = Surface::MakeScratch(recorder,
+                                                  dstInfo,
+                                                  std::move(label),
+                                                  budgeted,
+                                                  mipmapped,
+                                                  backingFit);
     if (!surface) {
         return nullptr;
     }
@@ -379,7 +392,7 @@ sk_sp<Image> CopyAsDraw(Recorder* recorder,
     paint.setBlendMode(SkBlendMode::kSrc);
     surface->getCanvas()->drawImage(image, -subset.left(), -subset.top(),
                                     SkFilterMode::kNearest, &paint);
-    // And the image draw into `surface` is flushed when it goes out of scope
+    surface->flushToDrawContext(drawContext);
     return surface->asImage();
 }
 
@@ -514,6 +527,7 @@ sk_sp<SkImage> RescaleImage(Recorder* recorder,
 }
 
 bool GenerateMipmaps(Recorder* recorder,
+                     DrawContext* drawContext,
                      sk_sp<TextureProxy> texture,
                      const SkColorInfo& colorInfo) {
     constexpr SkSamplingOptions kSamplingOptions = SkSamplingOptions(SkFilterMode::kLinear);
@@ -565,7 +579,7 @@ bool GenerateMipmaps(Recorder* recorder,
                                                    SkCanvas::kStrict_SrcRectConstraint);
 
         // Make sure the rescaling draw finishes before copying the results.
-        Flush(scratchSurface);
+        scratchSurface->flushToDrawContext(drawContext);
 
         sk_sp<CopyTextureToTextureTask> copyTask = CopyTextureToTextureTask::Make(
                 static_cast<const Surface*>(scratchSurface)->readSurfaceView().refProxy(),
@@ -576,7 +590,12 @@ bool GenerateMipmaps(Recorder* recorder,
         if (!copyTask) {
             return false;
         }
-        recorder->priv().add(std::move(copyTask));
+
+        if (drawContext) {
+            drawContext->recordDependency(std::move(copyTask));
+        } else {
+            recorder->priv().add(std::move(copyTask));
+        }
 
         scratchImg = scratchSurface->asImage();
         srcSize = dstSize;
@@ -719,8 +738,6 @@ public:
         return this;
     }
 
-    bool useLegacyFilterResultBlur() const override { return false; }
-
     // SkShaderBlurAlgorithm
     sk_sp<SkDevice> makeDevice(const SkImageInfo& imageInfo) const override {
         return skgpu::graphite::Device::Make(fRecorder,
