@@ -51,9 +51,9 @@
 #include "tests/Test.h"
 #include "tests/TestUtils.h"
 #include "tools/ToolUtils.h"
+#include "tools/ganesh/ProxyUtils.h"
 #include "tools/gpu/ContextType.h"
 #include "tools/gpu/ManagedBackendTexture.h"
-#include "tools/gpu/ProxyUtils.h"
 
 #include <array>
 #include <functional>
@@ -69,7 +69,7 @@
 #include "src/gpu/ganesh/gl/GrGLContext.h"
 #include "src/gpu/ganesh/gl/GrGLDefines.h"
 #include "src/gpu/ganesh/gl/GrGLGpu.h"
-#include "tools/gpu/gl/GLTestContext.h"
+#include "tools/ganesh/gl/GLTestContext.h"
 #endif
 
 #if defined(SK_METAL)
@@ -307,7 +307,7 @@ static void check_base_readbacks(GrDirectContext* dContext,
                                  skiatest::Reporter* reporter,
                                  const char* label) {
     if (isRGB(backendTex.getBackendFormat())) {
-        // readPixels is busted for the RGB backend format (skbug.com/8862)
+        // readPixels is busted for the RGB backend format (skbug.com/40040143)
         // TODO: add a GrColorType::kRGB_888 to fix the situation
         return;
     }
@@ -420,7 +420,7 @@ static void check_mipmaps(GrDirectContext* dContext,
                           skiatest::Reporter* reporter,
                           const char* label) {
 #ifdef SK_GL
-    // skbug.com/9141 (RGBA_F32 mipmaps appear to be broken on some Mali devices)
+    // skbug.com/40040438 (RGBA_F32 mipmaps appear to be broken on some Mali devices)
     if (GrBackendApi::kOpenGL == dContext->backend()) {
         GrGLGpu* glGPU = static_cast<GrGLGpu*>(dContext->priv().getGpu());
 
@@ -432,7 +432,7 @@ static void check_mipmaps(GrDirectContext* dContext,
 #endif
 
     if (isRGB(backendTex.getBackendFormat())) {
-        // readPixels is busted for the RGB backend format (skbug.com/8862)
+        // readPixels is busted for the RGB backend format (skbug.com/40040143)
         // TODO: add a GrColorType::kRGB_888 to fix the situation
         return;
     }
@@ -649,7 +649,7 @@ void color_type_backend_allocation_test(const sk_gpu_test::ContextInfo& ctxInfo,
         SkColorType colorType = combo.fColorType;
 
         if (GrBackendApi::kMetal == context->backend()) {
-            // skbug.com/9086 (Metal caps may not be handling RGBA32 correctly)
+            // skbug.com/40040379 (Metal caps may not be handling RGBA32 correctly)
             if (kRGBA_F32_SkColorType == combo.fColorType) {
                 continue;
             }
